#!/usr/bin/env python3
# dac8532.py
#
# Copyright (c) 2020-2022 Spring City Solutions LLC and other contributors
# Licensed under the Apache License, Version 2.0
#
# Need to have the rpi.gpio and spidev python libraries installed
#
# Usage:
#
# dac8532.py "port A or B" "integer value 0 to 65535"
#
# Hardware Links:
#
# Board Manufacturer Store:
# https://www.waveshare.com/High-Precision-AD-DA-Board.htm
#
# Board Manufacturer Wiki:
# https://www.waveshare.com/wiki/High-Precision_AD/DA_Board
#
# Links for ADS1256 chip:
# https://www.ti.com/product/ADS1256
# https://www.ti.com/lit/gpn/ads1256
# Book "Fundamentals of Precision ADC Noise Analysis" https://www.ti.com/lit/pdf/slyy192
# Journal Series "How delta-sigma ADCs work" https://www.ti.com/lit/pdf/slyt423 https://www.ti.com/lit/pdf/slyt438
# App Note "Digital Filter Types in Delta-Sigma ADCs" https://www.ti.com/lit/pdf/sbaa230
#
# Link for LM285 chip, connected to the ADS1256:
# https://www.ti.com/product/LM285-2.5-N
# https://www.ti.com/lit/gpn/lm285-2.5-n
#
# Link for DAC8532 chip:
# https://www.ti.com/product/DAC8532
# https://www.ti.com/lit/gpn/dac8532
#
# Spring City Solutions Links:
#
# Spring City Solutions Node-RED project page:
# https://www.springcitysolutions.com/nodered
#
# Spring City Solutions page for this node:
# https://www.springcitysolutions.com/nodered-waveshare-adda-shield
#
# Spring City Solutions Node-RED project email:
# nodered@springcitysolutions.com
# 
# Spring City Solutions Gitlab for this node:
# https://gitlab.com/SpringCitySolutionsLLC/waveshare-shield-adda-11010
#
# Patreon Page:
# https://www.patreon.com/springcitysolutions_nodered
#
# Software Links:
#
# Spring City Solutions Gitlab for this node:
# https://gitlab.com/SpringCitySolutionsLLC/waveshare-shield-adda-11010
#
# npmjs for this node:
# https://npmjs.org/package/node-red-contrib-waveshare-shield-adda-11010
#
# Node-RED flows for this node:
# https://flows.nodered.org/node/node-red-contrib-waveshare-shield-adda-11010
#
# Documentation Links:
#
# Gitlab wiki for this node (the master copy of list of links is here):
# https://gitlab.com/SpringCitySolutionsLLC/waveshare-shield-adda-11010/-/wikis/home
#
# Waveshare's libraries for this hardware:
# https://github.com/waveshare/High-Precision-AD-DA-Board
#
# Youtube video "How to set up":
# TODO
#
# Youtube video "How to use":
# TODO
#
# Youtube video "Testing Results":
# TODO

import RPi.GPIO as GPIO
import spidev
import sys

cs = 23
GPIO.setmode(GPIO.BCM)
GPIO.setwarnings(False)
GPIO.setup(cs, GPIO.OUT)
GPIO.output(cs, 1)

spi = spidev.SpiDev()
spi.open(0, 0)
spi.max_speed_hz = 20000
spi.mode = 0b01

firstbyte = 0x30

if sys.argv[1] == "A":
    firstbyte = 0x30
if sys.argv[1] == "B":
    firstbyte = 0x34

secondbyte = int(sys.argv[2]) >> 8
thirdbyte = int(sys.argv[2]) & 0xFF

GPIO.output(cs, 0)
spi.writebytes([firstbyte, secondbyte, thirdbyte])
GPIO.output(cs, 1)
